Learn R Programming

tntpr (version 1.2.1)

colors_tntp: TNTP colors

Description

This list of colors has been superseded by the new brand colors and the new function tntp_colors().

Usage

colors_tntp

Arguments

Format

An object of class character of length 34.

Examples

Run this code
tntp_colors()

Run the code above in your browser using DataLab